PrimitiveValue

Enum PrimitiveValue 

#[non_exhaustive]
pub enum PrimitiveValue {
Show 15 variants u8(u8), i8(i8), u16(u16), i16(i16), u32(u32), i32(i32), f32(f32), u64(u64), i64(i64), f64(f64), u128(u128), i128(i128), bool(bool), char(char), null,
}
A shuttle struct to pass around a primitive type and an associated value of the same type

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


u8(u8)



i8(i8)



u16(u16)



i16(i16)



u32(u32)



i32(i32)



f32(f32)



u64(u64)



i64(i64)



f64(f64)



u128(u128)



i128(i128)



bool(bool)



char(char)



null

Implementations

Source

impl PrimitiveValue

pub fn name(&self) -> &'static str

pub fn iter_names() -> impl Iterator<Item = &'static str>

Source

impl PrimitiveValue

pub const fn primitive(&self) -> Primitives

Returns the type of this primitive

pub fn as_be_bytes(&self) -> Box<[u8]>